@@ -174,6 +174,8 @@ OC.L10N.register(
     "Message deleted by you" : "Desaniciesti'l mensaxe",
     "Deleted user" : "Usuariu desaniciáu",
     "Unknown number" : "Númberu desconocíu",
+    "Administration" : "Alministración",
+    "System" : "Sistema",
     "%s (guest)" : "%s (convidáu)",
     "Message of {user}" : "Mensaxe de: {user}",
     "Talk conversations" : "Conversaciones de Talk",
@@ -640,23 +642,23 @@ OC.L10N.register(
     "No conversations found" : "Nun s'atopó nenguna conversación",
     "You have no unread mentions." : "Nun tienes nenguna mención ensin lleer.",
     "You have no unread messages." : "Nun tienes nengún mensaxe ensin lleer.",
-    "Users, groups and teams" : "Usuarios, grupos y equipos",
-    "Users and groups" : "Usuarios y grupos",
-    "Users and teams" : "Usuarios y equipos",
-    "Users" : "Usuarios",
-    "Groups and teams" : "Grupos y equipos",
-    "Groups" : "Grupos",
-    "Teams" : "Equipos",
-    "Other sources" : "Otros oríxenes",
     "An error occurred while performing the search" : "Prodúxose un error mentanto se facía la busca",
     "Conversation list" : "Llista de conversaciones",
     "New personal note" : "Nota personal nueva",
     "Unread mentions" : "Menciones ensin lleer",
-    "Open conversations" : "Abrir les conversaciones",
-    "New private conversation" : "Conversación privada nueva",
-    "Federated users" : "Usuarios federaos",
-    "No search results" : "Nun hai nengún resultáu de la busca",
     "Talk settings" : "Configuración de Talk",
+    "Users" : "Usuarios",
+    "Groups" : "Grupos",
+    "Teams" : "Equipos",
+    "Federated users" : "Usuarios federaos",
+    "New private conversation" : "Conversación privada nueva",
+    "Open conversations" : "Abrir les conversaciones",
+    "No search results" : "Nun hai nengún resultáu de la busca",
+    "Users, groups and teams" : "Usuarios, grupos y equipos",
+    "Users and groups" : "Usuarios y grupos",
+    "Users and teams" : "Usuarios y equipos",
+    "Groups and teams" : "Grupos y equipos",
+    "Other sources" : "Otros oríxenes",
     "You are currently waiting in the lobby" : "Tas na sala d'espera",
     "None" : "Nada",
     "No microphone available" : "Nun hai nengún micrófonu disponible",
