@@ -90,6 +90,8 @@ OC.L10N.register(
     "An administrator demoted {user} from moderator" : "Ur merour en deus lamet da {user} e droet habaskaer ",
     "{actor} shared a file which is no longer available" : "Restr rannet {actor} n'eo ket posupl kavout kenn",
     "You shared a file which is no longer available" : "Ar restr o peus rannet n'eo ket posupl kavout kenn",
+    "Administration" : "Merouriez",
+    "System" : "Sistem",
     "%s (guest)" : "%s (kouviat)",
     "Talk to %s" : "Komz da %s",
     "File is not shared, or shared but not with the user" : "N'eo ket rannet ar restr, pe n'eo ket rannet gan an implijour",
@@ -112,11 +114,11 @@ OC.L10N.register(
     "Join »%s«" : "Mont da »%s«",
     "Password request: %s" : "Ger-tremen goulennet : %s",
     "Private conversation" : "Diviz prevez",
-    "Deleted user (%s)" : "Lemel implijour (%s)",
+    "Deleted user (%s)" : "Implijour dilamet (%s)",
     "Dismiss notification" : "Arrest ar gemenadennoù",
     "Accept" : "Asantiñ",
     "{user} in {call}" : "{user} e {call}",
-    "Deleted user in {call}" : "Lemel implijer e {call}",
+    "Deleted user in {call}" : "Implijer dilamet e {call}",
     "{guest} (guest) in {call}" : "{guest} (kouviad) e {call}",
     "Guest in {call}" : "Kouvidi e {call}",
     "{user} sent you a private message" : "{user} en deus kaser deoc'h ur gemenadenn prevez",
@@ -300,12 +302,12 @@ OC.L10N.register(
     "Kiribati" : "Kiribati",
     "Comoros" : "Komorez",
     "Saint Kitts and Nevis" : "Saint Kitts ha Nevis",
-    "Korea, Democratic People's Republic of" : "Republik Poblel ha Demokratel Korea",
+    "Korea, Democratic People's Republic of" : "Korea, Republik Poblel ha Demokratel",
     "Korea, Republic of" : "Republik Korea",
     "Kuwait" : "Koweit",
     "Cayman Islands" : "Inizi Cayman",
     "Kazakhstan" : "Kazakstan",
-    "Lao People's Democratic Republic" : "Laos",
+    "Lao People's Democratic Republic" : "Lao, Republik Demokratel ar Bobl",
     "Lebanon" : "Liban",
     "Saint Lucia" : "Santez-Lusia",
     "Liechtenstein" : "Liechtenstein",
@@ -437,8 +439,8 @@ OC.L10N.register(
     "Invalid date, date format must be YYYY-MM-DD" : "Deizat fall, stumm an deizat a zo ret bezhañ BBBB-MM-DD",
     "Conversation not found" : "N'eo ket bet kavet an diviz",
     "Chat, video & audio-conferencing using WebRTC" : "Chat, video & audio-prezegenn gant WebRTC",
-    "Navigating away from the page will leave the call in {conversation}" : "Kuitat ar bajenn a laosko ar pelgomzadenn e {convzersation}",
-    "Leave call" : "Kuitat ar gemenadenn",
+    "Leave call" : "Kuitaat ar gemenadenn",
+    "Navigating away from the page will leave the call in {conversation}" : "Kuitaat ar bajenn a laosko ar pelgomzadenn e {convzersation}",
     "Stay in call" : "Chom er gemenadenn",
     "Discuss this file" : "Komz diwar benn ar restr-mañ",
     "Share this file with others to discuss it" : "Rannañ ar restr-mañ da reoù all evit komz diwar e-benn",
@@ -487,7 +489,7 @@ OC.L10N.register(
     "The trial could not be requested. Please try again later." : "An amprouadenn na c'hell ket bezhañ goulennet. Klaskit en dro goude.",
     "The account could not be deleted. Please try again later." : "Neo ket posupl lemel ar c'hont. Klaskit en dro goude",
     "URL of this Nextcloud instance" : "URL an azgoulenn Nextcloud",
-    "Full name of the user requesting the trial" : "Tout anv an implijer a goulenn an amprouadenn",
+    "Full name of the user requesting the trial" : "Anv klok an implijer a c'houlenn an taol esae",
     "Language" : "Yezh",
     "Country" : "Bro",
     "Request signaling server trial" : "Goulenn amproui arhent ar servijour",
@@ -501,7 +503,7 @@ OC.L10N.register(
     "Status: Checking connection" : "Stad : Ho gwiriañ ar genstagadenn",
     "OK: Running version: {version}" : "OK : o lakaat da dreiñ ar stumm : {version}",
     "Validate SSL certificate" : "Sertifikad SSL gwiriet",
-    "Delete this server" : "Lemel ar servijour",
+    "Delete this server" : "Dilemel ar servijer-mañ",
     "Test this server" : "Arnodañ ar servijour-mañ",
     "Shared secret" : "Secret rannet",
     "High-performance backend URL" : "URL ar vackend a labour buhan",
@@ -519,8 +521,8 @@ OC.L10N.register(
     "OK" : "OK",
     "Confirm" : "Kadarnañ",
     "Back" : "Distro",
-    "Cancel" : "Arrest",
-    "Calendar" : "Deiziadur",
+    "Cancel" : "Nullañ",
+    "Calendar" : "Deiziataer",
     "Save" : "Enrollañ",
     "Search participants" : "Klask implijer",
     "No results" : "Disoc'h ebet",
@@ -545,6 +547,7 @@ OC.L10N.register(
     "You need to be logged in to upload files" : "Ret eo deoc'h bezhañ deuet-tre evit pellkas restroù",
     "Drop your files to upload" : "Laoskit ho restroù evit pellkas",
     "Favorite" : "Pennroll",
+    "Date:" : "Deiziad:",
     "Hide details" : "Skoachañ ar munudoù",
     "Show details" : "Diskouel ar munudoù",
     "Disable" : "Disaotreañ",
@@ -552,26 +555,26 @@ OC.L10N.register(
     "Choose" : "Dibab",
     "Conversation settings" : "Stummoù diviz",
     "Personal" : "Personel",
-    "Do you really want to delete \"{displayName}\"?" : "Sur oc'h da lemel  \"{displayName}\" ?",
+    "Do you really want to delete \"{displayName}\"?" : "Sur oc'h da zilemel  \"{displayName}\"?",
     "Leave conversation" : "Kuitaat an diviz",
     "No" : "Nann",
-    "Delete conversation" : "Lemel an diviz",
+    "Delete conversation" : "Dilemel an diviz",
     "Password protection" : "Gwareziñ gant ur ger-tremen",
     "Start time (optional)" : "Amzer kregiñ (dibab)",
     "Edit" : "Cheñch",
     "More information" : "Muioc'h a ditouroù",
-    "Delete" : "Lemel",
+    "Delete" : "Dilemel",
     "Notifications" : "Kemennadennoù",
     "Log in" : "Kennaskañ",
     "Remove from favorites" : "Diverkañañ eus ar pennrolloù",
     "Add to favorites" : "Ouzhpennañ er pennrolloù",
     "You need to promote a new moderator before you can leave the conversation." : "Ret eo deoc'h lakaat unan bennak da moderatour a-rao kuitaat an diviz.",
-    "Users and groups" : "Implijourienn ha strolladoù",
+    "An error occurred while performing the search" : "Ur fazi a zo bet en ur ober an enklask",
     "Users" : "Implijer",
     "Groups" : "Strolladoù",
-    "Other sources" : "Orin all",
-    "An error occurred while performing the search" : "Ur fazi a zo bet en ur ober an enklask",
     "No search results" : "Disoc'h enklask ebet",
+    "Users and groups" : "Implijourienn ha strolladoù",
+    "Other sources" : "Orin all",
     "You are currently waiting in the lobby" : "Ho gortoz er sal gortoz emaoc'h",
     "None" : "Hini ebet",
     "Select microphone" : "Choaz ur mikro",
@@ -607,8 +610,8 @@ OC.L10N.register(
     "Join" : "Kejañ",
     "moderator" : "habaskaer",
     "guest" : "kouviad",
-    "Remove participant" : "Lemel an den",
-    "Demote from moderator" : "Lemel eus ar moderatourienn",
+    "Remove participant" : "Disachañ an den",
+    "Demote from moderator" : "Tennañ ar gwirioù kerreizhañ",
     "Promote to moderator" : "Lakaat da moderatour",
     "Add users or groups" : "Ouzhpennañ implijourienn pe strolladoù",
     "Add users" : "Ouzhpennañ implijer ",
@@ -685,8 +688,8 @@ OC.L10N.register(
     "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
     "An error occurred while fetching the participants" : "Ur fazi a zo bet en ur pakañ an tud",
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Ho klask mont en diviz emaoc'h p'ho peus un dalc'h en ur prenestr pe ardivink all. N'eo ket douget c'hoaz gant Nextcloud Talk. Petra o peus c'hoant ober ?",
-    "Join here" : "Kejañ amañ",
     "Leave this page" : "Kuitaat ar bajenn",
+    "Join here" : "Kejañ amañ",
     "Lost connection to signaling server. Trying to reconnect." : "Kenstagadenn gant ar servijour arhent kollet. O klask adkemprenn.",
     "Establishing signaling connection is taking longer than expected …" : "Lakaat an arhent kenstagañ a zo hiroc'h eget gortozet ...",
     "Failed to establish signaling connection. Retrying …" : "C'hwitet da lakaat an arhent kemprenn. O klask en dro ...",
