@@ -5,6 +5,8 @@ OC.L10N.register(
     "Talk" : "Hablar",
     "Guest" : "Invitado",
     "Message deleted by author" : "Mensaje eliminado por el autor",
+    "Administration" : "Administración",
+    "System" : "Sistema",
     "File is too big" : "El archivo es demasiado grande.",
     "Invalid file provided" : "Archivo proporcionado inválido",
     "Invalid image" : "Imagen inválida",
@@ -40,6 +42,7 @@ OC.L10N.register(
     "Country" : "País",
     "Status" : "Estatus",
     "Created at" : "Creado en",
+    "_%n user_::_%n users_" : ["%n usuario","%n usuarios","%n usuarios"],
     "TURN server protocols" : "Protocolos del servidor TURN",
     "Failed" : "Error",
     "OK" : "OK",
@@ -65,6 +68,7 @@ OC.L10N.register(
     "Disable" : "Deshabilitar",
     "Enable" : "Activar",
     "Choose" : "Elige",
+    "The file must be a PNG or JPG" : "El archivo debe ser PNG o JPG",
     "Restricted" : "Restringido",
     "Personal" : "Personal",
     "Leave conversation" : "Dejar la conversación",
