@@ -68,6 +68,8 @@ OC.L10N.register(
     "{actor} shared a file which is no longer available" : "{actor} compartió un archivo que ya no está disponible",
     "You shared a file which is no longer available" : "Compartiste un archivo que ya no está disponible",
     "Message deleted by author" : "Mensaje eliminado por el autor",
+    "Administration" : "Administración",
+    "System" : "Sistema",
     "%s (guest)" : "%s (invitado)",
     "Talk conversations" : "Conversaciones de Talk",
     "Talk to %s" : "Hablar con %s",
@@ -404,11 +406,11 @@ OC.L10N.register(
     "Log in" : "Ingresar",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a favoritos",
+    "Clear filter" : "Limpiar filtro",
+    "Unread mentions" : "Menciones sin leer",
     "Users" : " Usuarios",
     "Groups" : "Grupos",
     "Teams" : "Equipos",
-    "Clear filter" : "Limpiar filtro",
-    "Unread mentions" : "Menciones sin leer",
     "No search results" : "No hay resultados de búsqueda",
     "None" : "Ninguno",
     "Select a device" : "Seleccionar un dispositivo",
