@@ -171,6 +171,8 @@ OC.L10N.register(
     "Message deleted by author" : "Viestin lähettäjä poisti viestin",
     "Deleted user" : "Poistettu käyttäjä",
     "Unknown number" : "Tuntematon numero",
+    "Administration" : "Ylläpito",
+    "System" : "Järjestelmä",
     "%s (guest)" : "%s (vieras)",
     "Message of {user} in {conversation}" : "Käyttäjän {user} viesti keskustelussa {conversation}",
     "Message of {user}" : "Käyttäjän {user} viesti",
@@ -501,8 +503,8 @@ OC.L10N.register(
     "Invalid date, date format must be YYYY-MM-DD" : "Virheellinen päiväys, päiväyksen muoto tulee olla YYYY-MM-DD",
     "Conversation not found" : "Keskustelua ei löydy",
     "Chat, video & audio-conferencing using WebRTC" : "Keskustelu ja video- sekä äänineuvottelut WebRTC:tä käyttäen",
-    "Navigating away from the page will leave the call in {conversation}" : "Sivulta poistuminen päättää puhelun keskustelussa {conversation}",
     "Leave call" : "Poistu puhelusta",
+    "Navigating away from the page will leave the call in {conversation}" : "Sivulta poistuminen päättää puhelun keskustelussa {conversation}",
     "Stay in call" : "Pysy puhelussa",
     "Discuss this file" : "Keskustele tästä tiedostosta",
     "Share this file with others to discuss it" : "Jaa tämä tiedosto muiden kanssa keskustellaksesi siitä",
@@ -809,14 +811,6 @@ OC.L10N.register(
     "No conversations found" : "Keskusteluja ei löytynyt",
     "You have no unread mentions." : "Sinulla ei ole lukemattomia mainintoja.",
     "You have no unread messages." : "Sinulla ei ole lukemattomia viestejä.",
-    "Users, groups and teams" : "Käyttäjät, ryhmät ja tiimit",
-    "Users and groups" : "Käyttäjät ja ryhmät",
-    "Users and teams" : "Käyttäjät ja tiimit",
-    "Users" : "Käyttäjät",
-    "Groups and teams" : "Ryhmät ja tiimit",
-    "Groups" : "Ryhmät",
-    "Teams" : "Tiimit",
-    "Other sources" : "Muut lähteet",
     "An error occurred while performing the search" : "Hakua suorittaessa tapahtui virhe",
     "Conversation list" : "Keskustelulista",
     "Filter unread mentions" : "Suodata lukemattomat maininnat",
@@ -827,12 +821,20 @@ OC.L10N.register(
     "Join open conversations" : "Liity avoimiin keskusteluihin",
     "Clear filter" : "Tyhjennä suodatin",
     "Unread mentions" : "Lukemattomat maininnat",
-    "New group conversation" : "Uusi ryhmäkeskustelu",
-    "Open conversations" : "Avaa keskustelut",
-    "New private conversation" : "Uusi yksityinen keskustelu",
-    "Federated users" : "Federoidut käyttäjät",
-    "No search results" : "Ei hakutuloksia",
     "Talk settings" : "Talk-asetukset",
+    "Users" : "Käyttäjät",
+    "Groups" : "Ryhmät",
+    "Teams" : "Tiimit",
+    "Federated users" : "Federoidut käyttäjät",
+    "New private conversation" : "Uusi yksityinen keskustelu",
+    "Open conversations" : "Avaa keskustelut",
+    "No search results" : "Ei hakutuloksia",
+    "Users, groups and teams" : "Käyttäjät, ryhmät ja tiimit",
+    "Users and groups" : "Käyttäjät ja ryhmät",
+    "Users and teams" : "Käyttäjät ja tiimit",
+    "Groups and teams" : "Ryhmät ja tiimit",
+    "Other sources" : "Muut lähteet",
+    "New group conversation" : "Uusi ryhmäkeskustelu",
     "The meeting will start soon" : "Tämä kokous alkaa pian",
     "This meeting is scheduled for {startTime}" : "Kokous on ajoitettu alkavaksi {startTime}",
     "You are currently waiting in the lobby" : "Odotat parhaillaan aulassa",
@@ -1267,8 +1269,8 @@ OC.L10N.register(
     "An error occurred while fetching the participants" : "Virhe osallistujia noudettaessa",
     "Invitations sent" : "Kutsut lähetetty",
     "Error occurred when sending invitations" : "Kutsujen lähetyksessä tapahtui virhe",
-    "Join here" : "Liity tähän",
     "Leave this page" : "Poistu tältä sivulta",
+    "Join here" : "Liity tähän",
     "An error occurred while creating breakout rooms" : "Pienryhmätiloja luotaessa tapahtui virhe",
     "{guest} (guest)" : "{guest} (vieras)",
     "Failed to add reaction" : "Reaktion lisääminen epäonnistui",
