@@ -63,6 +63,8 @@ OC.L10N.register(
     "{actor} deleted a message" : "הודעה נמחקה על ידי {actor}",
     "You deleted a message" : "מחקת הודעה",
     "Message deleted by author" : "ההודעה נמחקה על ידי מי שפרסם אותה",
+    "Administration" : "ניהול",
+    "System" : "מערכת",
     "Talk conversations" : "דיוני שיח",
     "File is too big" : "הקובץ גדול מדי",
     "Invalid file provided" : "הקובץ שסופק שגוי",
@@ -339,8 +341,8 @@ OC.L10N.register(
     "Federation" : "איגוד",
     "Invalid date, date format must be YYYY-MM-DD" : "תאריך לא חוקי, תבנית התאריך חייבת להיות YYYY-MM-DD",
     "Conversation not found" : "הדיון לא נמצא",
-    "Navigating away from the page will leave the call in {conversation}" : "ניווט מחוץ לעמוד תנתק את השיחה שב־{conversation}",
     "Leave call" : "יציאה מהשיחה",
+    "Navigating away from the page will leave the call in {conversation}" : "ניווט מחוץ לעמוד תנתק את השיחה שב־{conversation}",
     "Stay in call" : "להישאר בשיחה",
     "Discuss this file" : "לדון על הקובץ הזה",
     "Share this file with others to discuss it" : "שיתוף הקובץ הזה לדיונם של אחרים",
@@ -453,11 +455,11 @@ OC.L10N.register(
     "Remove from favorites" : "הסרה מהמועדפים",
     "Add to favorites" : "הוספה למועדפים",
     "No matches found" : "לא נמצאו התאמות",
+    "An error occurred while performing the search" : "אירעה שגיאה בעת ביצוע החיפוש",
+    "Clear filter" : "מחיקת מסנן",
     "Users" : "משתמשים",
     "Groups" : "קבוצות",
     "Other sources" : "מקורות אחרים",
-    "An error occurred while performing the search" : "אירעה שגיאה בעת ביצוע החיפוש",
-    "Clear filter" : "מחיקת מסנן",
     "You are currently waiting in the lobby" : "הנך בהמתנה בלובי",
     "None" : "אין",
     "Devices" : "מכשירים",
