@@ -137,6 +137,8 @@ OC.L10N.register(
     "Message deleted by {actor}" : "Poruku je izbrisao {actor}",
     "Message deleted by you" : "Poruku ste vi izbrisali",
     "Deleted user" : "Izbrisan korisnik",
+    "Administration" : "Administracija",
+    "System" : "Sustav",
     "%s (guest)" : "%s (gost)",
     "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} je završio poziv s %n gostom (Trajanje {duration})","{actor} je završio poziv s %n gosta (Trajanje {duration})","{actor} je završio poziv s %n gostiju (Trajanje {duration})"],
     "{actor} ended the call with {user1} (Duration {duration})" : "{actor} je završio poziv s {user1} (Trajanje {duration})",
@@ -504,8 +506,8 @@ OC.L10N.register(
     "Invalid date, date format must be YYYY-MM-DD" : "Nevažeći datum, oblik datuma mora biti GGGG-MM-DD",
     "Conversation not found" : "Razgovor nije pronađen",
     "Chat, video & audio-conferencing using WebRTC" : "Razmjena poruka, videopozivi i glasovne konferencije putem WebRTC-a",
-    "Navigating away from the page will leave the call in {conversation}" : "Zatvaranjem stranice napustit ćete poziv u {conversation}",
     "Leave call" : "Napusti poziv",
+    "Navigating away from the page will leave the call in {conversation}" : "Zatvaranjem stranice napustit ćete poziv u {conversation}",
     "Stay in call" : "Ostani u pozivu",
     "Discuss this file" : "Raspravi o ovoj datoteci",
     "Share this file with others to discuss it" : "Podijeli ovu datoteku s drugima radi rasprave",
@@ -571,7 +573,6 @@ OC.L10N.register(
     "Delete the signaling server account" : "Brisanje računa signalnog poslužitelja",
     "_%n user_::_%n users_" : ["%n korisnik","%n korisnika","%n korisnika"],
     "Installed version: {version}" : "Instalirana inačica: {version}",
-    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/.../nextcloud/apps/talk_matterbridge/bin/\"." : "Matterbridge ima netočna dopuštenja. Provjerite je li binarna datoteka Matterbridgea u vlasništvu točnog korisnika i može li se izvršiti. Možete je pronaći u „/.../nextcloud/apps/talk_matterbridge/bin/“.",
     "Matterbridge binary was not found or couldn't be executed." : "Binarna datoteka Matterbridge nije pronađena ili se ne može izvršiti.",
     "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Put do binarnog programa Matterbridge također možete ručno postaviti u samoj konfiguraciji. Dodatne informacije potražite u {linkstart}dokumentaciji za integraciju Matterbridgea{linkend}.",
     "Downloading …" : "Preuzimanje…",
@@ -741,17 +742,17 @@ OC.L10N.register(
     "Conversation actions" : "Radnje razgovora",
     "No matches found" : "Nema pronađenih podudaranja",
     "No conversations found" : "Nije pronađen nijedan razgovor",
-    "Users and groups" : "Korisnici i grupe",
-    "Users" : "Korisnici",
-    "Groups" : "Grupe",
-    "Other sources" : "Drugi izvori",
     "An error occurred while performing the search" : "Došlo je do pogreške pri pretraživanju",
     "Conversation list" : "Popis razgovora",
     "Clear filter" : "Ukloni filtar",
     "Unread mentions" : "Nepročitana spominjanja",
+    "Talk settings" : "Postavke razgovora",
+    "Users" : "Korisnici",
+    "Groups" : "Grupe",
     "Open conversations" : "Otvori razgovore",
     "No search results" : "Nema rezultata pretraživanja",
-    "Talk settings" : "Postavke razgovora",
+    "Users and groups" : "Korisnici i grupe",
+    "Other sources" : "Drugi izvori",
     "The meeting will start soon" : "Sastanak počinje uskoro",
     "This meeting is scheduled for {startTime}" : "Sastanak počinje u {startTime}",
     "You are currently waiting in the lobby" : "Trenutno čekate u predvorju",
@@ -1035,8 +1036,8 @@ OC.L10N.register(
     "Invitations sent" : "Pozivnice su poslane",
     "Error occurred when sending invitations" : "Došlo je do pogreške pri slanju pozivnica",
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Pokušavate se pridružiti razgovoru dok imate otvorenu sesiju u drugom prozoru ili na drugom uređaju. Nextcloud Talk trenutačno ne podržava tu radnju. Što želite učiniti?",
-    "Join here" : "Pridruži se ovdje",
     "Leave this page" : "Napusti ovu stranicu",
+    "Join here" : "Pridruži se ovdje",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Nextcloud Talk ne podržava trenutni preglednik. Preuzmite najnoviju inačicu preglednika Mozilla Firefox, Microsoft Edge, Google Chrome, Opera ili Apple Safari.",
     "Lost connection to signaling server. Trying to reconnect." : "Veza sa signalnim poslužiteljem je prekinuta. Pokušavam se ponovno povezati.",
     "Establishing signaling connection is taking longer than expected …" : "Uspostavljanje signalne veze traje duže od očekivanog…",
