@@ -22,6 +22,8 @@ OC.L10N.register(
     "{actor} created the conversation" : "{actor} membuat sebuah percakapan",
     "You created the conversation" : "Anda membuat sebuah percakapan",
     "Message deleted by author" : "Pesan dihapus oleh penyusun",
+    "Administration" : "Administrasi",
+    "System" : "Sistem",
     "File is too big" : "Berkas terlalu besar",
     "Invalid file provided" : "Berkas tidak valid",
     "Invalid image" : "Gambar tidak valid",
@@ -274,6 +276,7 @@ OC.L10N.register(
     "Reset" : "Setel ulang",
     "Back" : "Kembali",
     "Cancel" : "Membatalkan",
+    "Loading …" : "Memuat …",
     "No upcoming events" : "Tdak ada acara mendatang",
     "Calendar" : "Kalender",
     "Attendees" : "Peserta",
@@ -303,12 +306,13 @@ OC.L10N.register(
     "Mark as unread" : "Tandai belum dibaca",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Tambah ke favorit",
+    "Clear filter" : "Bersihkan filter",
     "Users" : "Pengguna",
     "Groups" : "Grup",
-    "Clear filter" : "Bersihkan filter",
     "No search results" : "Tidak ada hasil pencarian",
     "None" : "Tidak ada",
     "Invalid path selected" : "Jalur terpilih invalid",
+    "Blur" : "Kabur",
     "Upload" : "Unggah",
     "Files" : "Berkas",
     "Unread messages" : "Pesan belum dibaca",
