@@ -56,6 +56,8 @@ OC.L10N.register(
     "{actor} shared a file which is no longer available" : "{actor} deildi skrá sem ekki er lengur tiltæk",
     "You shared a file which is no longer available" : "Þú deildir skrá sem ekki er lengur tiltæk",
     "Message deleted by author" : "Skilaboðum eytt af höfundi",
+    "Administration" : "Stjórnun",
+    "System" : "Kerfið",
     "%s (guest)" : "%s (gestur)",
     "Talk conversations" : "Samtöl",
     "Talk to %s" : "Tala við %s",
@@ -451,13 +453,13 @@ OC.L10N.register(
     "Add to favorites" : "Bæta í eftirlæti",
     "You need to promote a new moderator before you can leave the conversation." : "Þú þarft að uppfæra einhvern í stöðu umsjónarmanna áður en þú getur hætt í samtalinu.",
     "No matches found" : "Engar samsvaranir fundust",
+    "Create a new conversation" : "Hefja nýtt samtal",
+    "Clear filter" : "Hreinsa síu",
     "Users" : "Notendur",
     "Groups" : "Hópar",
     "Teams" : "Teymi",
-    "Create a new conversation" : "Hefja nýtt samtal",
-    "Clear filter" : "Hreinsa síu",
-    "New group conversation" : "Nýtt hópsamtal…",
     "No search results" : "Engar leitarniðurstöður",
+    "New group conversation" : "Nýtt hópsamtal…",
     "You are currently waiting in the lobby" : "You are currently waiting in the lobby",
     "None" : "Enginn",
     "Select a device" : "Veldu tæki",
