@@ -138,6 +138,8 @@ OC.L10N.register(
     "Message deleted by you" : "Jūs ištrynėte žinutę",
     "Deleted user" : "Ištrintas naudotojas",
     "Unknown number" : "Nežinomas numeris",
+    "Administration" : "Administravimas",
+    "System" : "Sistema",
     "%s (guest)" : "%s (svečias)",
     "Call ended (Duration {duration})" : "Skambutis baigtas (Trukmė {duration})",
     "Call was ended, as it reached the maximum call duration (Duration {duration})" : "Skambutis buvo užbaigtas, nes jis pasiekė didžiausią skambučio trukmę (Trukmė {duration})",
@@ -477,6 +479,7 @@ OC.L10N.register(
     "Test this server" : "Išbandyti šį serverį",
     "SIP configuration saved!" : "SIP konfigūracija įrašyta!",
     "Phone number (Country)" : "Telefono numeris (Šalis)",
+    "Available features" : "Prieinamos ypatybės",
     "STUN server URL" : "STUN serverio URL",
     "The server address is invalid" : "Serverio adresas yra neteisingas",
     "STUN settings saved" : "STUN nustatymai įrašyti",
@@ -493,10 +496,16 @@ OC.L10N.register(
     "Failed" : "Nepavyko",
     "OK" : "Gerai",
     "Checking …" : "Tikrinama…",
+    "Assignment method" : "Priskyrimo metodas",
+    "Automatically assign participants" : "Automatiškai priskirti dalyvius",
+    "Manually assign participants" : "Rankiniu būdu priskirti dalyvius",
+    "Allow participants to choose" : "Leisti dalyviams pasirinkti",
     "Confirm" : "Patvirtinti",
     "Reset" : "Atstatyti",
     "Room {roomNumber}" : "Kambarys {roomNumber}",
+    "Unassigned participants" : "Nepriskirti dalyviai",
     "Back" : "Atgal",
+    "Assign" : "Priskirti",
     "Cancel" : "Atsisakyti",
     "Now" : "Dabar",
     "Unknown error occurred" : "Įvyko nežinoma klaida",
@@ -520,23 +529,29 @@ OC.L10N.register(
     "Next page of videos" : "Kitas vaizdo įrašų puslapis",
     "Connecting …" : "Jungiamasi…",
     "Calling …" : "Skambinama…",
+    "Waiting for {user} to join the call" : "Laukiama, kol {user} prisijungs prie skambučio",
     "Waiting for others to join the call …" : "Laukiama, kol kiti prisijungs prie skambučio…",
     "You can invite others in the participant tab of the sidebar" : "Galite pakviesti kitus žmonės šoninėje juostoje, dalyvių kortelėje",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Galite pakviesti kitus žmonės šoninėje juostoje, dalyvių kortelėje arba bendrindami šią nuorodą, skirtą pakviesti kitus asmenis!",
     "Share this link to invite others!" : "Bendrinkite šią nuorodą, norėdami pakviesti kitus!",
     "Copy link" : "Kopijuoti nuorodą",
     "You are not allowed to enable audio" : "Jums neleidžiama įjungti garsą",
+    "No audio. Click to select device" : "Nėra garso. Spustelėkite norėdami pasirinkti įrenginį",
     "Mute audio" : "Nutildyti garsą",
     "Mute audio (M)" : "Nutildyti garsą (M)",
     "Unmute audio" : "Įjungti garsą",
     "Unmute audio (M)" : "Įjungti garsą (M)",
     "Access to camera was denied" : "Prieiga prie kameros buvo uždrausta",
+    "Error while accessing camera: It is likely in use by another program" : "Klaida gaunant prieigą prie kameros: Tikėtina, kad ją naudoja kita programa",
     "Error while accessing camera" : "Klaida gaunant prieigą prie kameros",
     "You are not allowed to enable video" : "Jums neleidžiama įjungti vaizdą",
+    "No video. Click to select device" : "Nėra vaizdo. Spustelėkite norėdami pasirinkti įrenginį",
     "Disable video" : "Išjungti vaizdą",
     "Disable video (V)" : "Išjungti vaizdą (V)",
     "Enable video" : "Įjungti vaizdą",
     "Enable video (V)" : "Įjungti vaizdą (V)",
+    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Įjungti vaizdą – Pirmą kartą įjungiant vaizdą, jūsų ryšys bus trumpam pertrauktas",
+    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Įjungti vaizdą (V) – Pirmą kartą įjungiant vaizdą, jūsų ryšys bus trumpam pertrauktas",
     "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Įjungti vaizdą. Pirmą kartą įjungiant vaizdą, jūsų ryšys bus trumpam pertrauktas",
     "You" : "Jūs",
     "Mute" : "Nutildyti",
@@ -635,26 +650,26 @@ OC.L10N.register(
     "Accept invitation" : "Priimti pakvietimą",
     "No matches found" : "Nerasta jokių atitikmenų",
     "You have no unread messages." : "Jūs neturite neskaitytų žinučių.",
-    "Users, groups and teams" : "Naudotojai, grupės ir komandos",
-    "Users and groups" : "Naudotojai ir grupės",
-    "Users and teams" : "Naudotojai ir komandos",
-    "Users" : "Naudotojai",
-    "Groups and teams" : "Grupės ir komandos",
-    "Groups" : "Grupės",
-    "Teams" : "Komandos",
-    "Other sources" : "Kiti šaltiniai",
     "An error occurred while performing the search" : "Atliekant paiešką, įvyko klaida",
     "Conversation list" : "Pokalbių sąrašas",
     "Clear filters" : "Išvalyti filtrus",
     "Create a new conversation" : "Sukurti naują pokalbį",
     "Join open conversations" : "Prisijungti prie atvirų pokalbių",
     "Clear filter" : "Išvalyti filtrą",
-    "New group conversation" : "Naujas grupės pokalbis",
-    "Open conversations" : "Atviri pokalbiai",
-    "New private conversation" : "Naujas privatus pokalbis",
-    "No search results" : "Nėra paieškos rezultatų",
     "Back to conversations" : "Atgal į pokalbius",
     "Talk settings" : "Pokalbių nustatymai",
+    "Users" : "Naudotojai",
+    "Groups" : "Grupės",
+    "Teams" : "Komandos",
+    "New private conversation" : "Naujas privatus pokalbis",
+    "Open conversations" : "Atviri pokalbiai",
+    "No search results" : "Nėra paieškos rezultatų",
+    "Users, groups and teams" : "Naudotojai, grupės ir komandos",
+    "Users and groups" : "Naudotojai ir grupės",
+    "Users and teams" : "Naudotojai ir komandos",
+    "Groups and teams" : "Grupės ir komandos",
+    "Other sources" : "Kiti šaltiniai",
+    "New group conversation" : "Naujas grupės pokalbis",
     "The meeting will start soon" : "Susitikimas netrukus prasidės",
     "You are currently waiting in the lobby" : "Šiuo metu laukiate laukimo salėje",
     "None" : "Nėra",
