@@ -58,6 +58,8 @@ OC.L10N.register(
     "{actor} shared a file which is no longer available" : "{actor} kopīgoja datni, kas vairs nav pieejama",
     "You shared a file which is no longer available" : "Jūs kopīgojāt datni, kas vairs nav pieejama",
     "Message deleted by author" : "Ziņojumu izdzēsa autors",
+    "Administration" : "Pārvaldīšana",
+    "System" : "Sistēma",
     "%s (guest)" : "%s (viesis)",
     "Talk conversations" : "Sarunas",
     "Talk to %s" : "Runāt ar %s",
@@ -381,6 +383,8 @@ OC.L10N.register(
     "Cancel" : "Atcelt",
     "Loading …" : "Ielādē…",
     "No upcoming events" : "Nav gaidāmu notikumu",
+    "From" : "No",
+    "To" : "Līdz",
     "Calendar" : "Kalendārs",
     "Attendees" : "Apmeklētāji",
     "Save" : "Saglabāt",
@@ -404,7 +408,7 @@ OC.L10N.register(
     "Disable" : "Deaktivēt",
     "Enable" : "Iespējot",
     "Choose" : "Izvēlēties",
-    "The file must be a PNG or JPG" : "Failam jābūt PNG vai JPG",
+    "The file must be a PNG or JPG" : "Datnei jābūt PNG vai JPG",
     "Restricted" : "Ierobežota",
     "Personal" : "Personīgs",
     "Setup overview" : "Uzstādīšanas pārskats",
@@ -422,9 +426,9 @@ OC.L10N.register(
     "Add to favorites" : "Pievienot izlasei",
     "You need to promote a new moderator before you can leave the conversation." : "Pirms sarunas atstāšanas ir jāieceļ jauns regulētājs.",
     "You have no unread mentions." : "Nav nelasītu pieminēšanu.",
+    "Clear filter" : "Notīrīt atlasi",
     "Users" : "Lietotāji",
     "Groups" : "Grupas",
-    "Clear filter" : "Notīrīt atlasi",
     "None" : "Nav",
     "Devices" : "Ierīces",
     "No audio" : "Nav audio",
@@ -456,6 +460,7 @@ OC.L10N.register(
     "Participants" : "Dalībnieki",
     "Chat" : "Tērzēt",
     "Details" : "Detaļas",
+    "From User" : "No lietotāja",
     "Load more results" : "Ielādēt vairāk iznākumu",
     "Projects" : "Projekti",
     "Link to a conversation" : "Saite uz sarunu",
@@ -467,19 +472,22 @@ OC.L10N.register(
     "Keyboard shortcuts" : "Tastatūras saīsnes",
     "Search" : "Meklēt",
     "Start call" : "Sākt zvanu",
+    "You are not allowed to enable screensharing" : "Nav ļauts iespējot ekrāna kopīgošanu",
+    "No screensharing" : "Nav ekrāna kopīgošanas",
     "Screensharing options" : "Ekrāna kopīgošanas iespējas",
-    "Enable screensharing" : "Iespējot ekrāna koplietošanu",
-    "Screensharing requires the page to be loaded through HTTPS." : "Lai koplietotu ekrānu, lapa jāielādē, izmantojot HTTPS.",
+    "Enable screensharing" : "Iespējot ekrāna kopīgošanu",
+    "Screensharing requires the page to be loaded through HTTPS." : "Ekrāna kopīgošanai ir nepieciešams lapu ielādēt ar HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Ekrāna koplietošana darbojas tikai ar Firefox 52. vai jaunāku versiju.",
-    "Screensharing extension is required to share your screen." : "Lai koplietotu ekrānu, ir nepieciešams ekrāna koplietošanas paplašinājums.",
+    "Screensharing extension is required to share your screen." : "Ir nepieciešams ekrāna kopīgošanas paplašinājums, lai kopīgotu savu ekrānu.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Lai koplietotu ekrānu, lūdzu, izmantojiet citu pārlūkprogrammu, piemēram, Firefox vai Chrome.",
-    "An error occurred while starting screensharing." : "Startējot ekrāna koplietošanu, radās kļūda.",
+    "An error occurred while starting screensharing." : "Ekrāna kopīgošanas uzsākšanas laikā atgadījās kļūda.",
     "Show your screen" : "Rādīt savu ekrānu",
-    "Stop screensharing" : "Apturēt ekrāna koplietošanu",
+    "Stop screensharing" : "Apturēt ekrāna kopīgošanu",
     "Grid view" : "Režģa izkārtojums",
     "Start recording" : "Uzsākt ierakstīšanu",
     "Select a region" : "Izvēlieties reģionu",
     "Submit" : "Iesniegt",
+    "Duplicate session" : "Pavairot sesiju",
     "Join a conversation or start a new one" : "Pievienoties sarunai vai sākt jaunu",
     "User" : "Lietotājs",
     "Password" : "Parole",
