@@ -130,6 +130,8 @@ OC.L10N.register(
     "Someone voted on the poll {poll}" : "Некој гласаше на анкетата {poll}",
     "Message deleted by author" : "Пораката е избришана од авторот",
     "Deleted user" : "Избришан корисник",
+    "Administration" : "Администрација",
+    "System" : "Систем",
     "%s (guest)" : "%s (гостин)",
     "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} го заврши повикот со 1 гостин (Времетраење {duration})","{actor} го заврши повикот со %n гости (Времетраење {duration})"],
     "{actor} ended the call with {user1} (Duration {duration})" : "{actor} го заврши повикот со {user1} (Времетраење {duration})",
@@ -674,15 +676,15 @@ OC.L10N.register(
     "Conversation actions" : "Дејства за разговорот",
     "No matches found" : "Не се пронајдени совпаѓања",
     "No conversations found" : "Нема пронајдено разговори",
-    "Users and groups" : "Корисници и групи",
-    "Users" : "Корисници",
-    "Groups" : "Групи",
-    "Other sources" : "Други извори",
     "An error occurred while performing the search" : "Настана грешка при обидот за пребарување",
     "Create a new conversation" : "Креирај нов разговор",
     "Clear filter" : "Исчисти филтри",
-    "No search results" : "Нема резултати од пребарувањето",
     "Talk settings" : "Параметри за Talk",
+    "Users" : "Корисници",
+    "Groups" : "Групи",
+    "No search results" : "Нема резултати од пребарувањето",
+    "Users and groups" : "Корисници и групи",
+    "Other sources" : "Други извори",
     "You are currently waiting in the lobby" : "Моментално чекате во лобито",
     "None" : "Ништо",
     "Select microphone" : "Избери микрофон",
@@ -971,8 +973,8 @@ OC.L10N.register(
     "Could not send invitation to {actorId}" : "Неможе да се ипспрати покана до {actorId}",
     "Invitations sent" : "Поканите се испратени",
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Се обидувате да се приклучите на разговор додека имате активна сесија во друг прозорец или уред. Ова во моментов не е поддржано. Што сакаш да правиш?",
-    "Join here" : "Приклучи се овде",
     "Leave this page" : "Напушти ја оваа страна",
+    "Join here" : "Приклучи се овде",
     "{guest} (guest)" : "{guest} (guest)",
     "An error occurred while submitting your vote" : "Настана грешка при гласање",
     "An error occurred while ending the poll" : "Настана грешка при затварање на анкетата",
