@@ -111,6 +111,8 @@ OC.L10N.register(
     "Message deleted by you" : "Ați șters mesajul",
     "Deleted user" : "Utilizator șters",
     "Unknown number" : "Număr necunoscut",
+    "Administration" : "Administrare",
+    "System" : "Sistem",
     "{actor} ended the call with {user1} (Duration {duration})" : "{actor} a închis apelul cu {user1} (Durată {duration})",
     "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} a închis apelul cu {user1} și {user2} (Durată {duration})",
     "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} a încheiat apelul cu {user1}, {user2} și {user3} (Durată {duration})",
@@ -432,8 +434,8 @@ OC.L10N.register(
     "Federation" : "Federare",
     "Invalid date, date format must be YYYY-MM-DD" : "Dată invalidă, formatul trebuie să fie AAAA-LL-ZZ",
     "Conversation not found" : "Conversație negăsită",
-    "Navigating away from the page will leave the call in {conversation}" : "Părăsind pagina se va părăsi conversația {conversation}",
     "Leave call" : "Părăsește videoconferința",
+    "Navigating away from the page will leave the call in {conversation}" : "Părăsind pagina se va părăsi conversația {conversation}",
     "Stay in call" : "Rămâneți în videoconferință",
     "Discuss this file" : "Discutați acest fișier",
     "Share this file with others to discuss it" : "Partajați acest fișier cu ceilalți pentru a-l discuta",
@@ -617,10 +619,6 @@ OC.L10N.register(
     "No conversations found" : "Nu sunt conversații",
     "You have no unread mentions." : "Nu aveți menționări necitite.",
     "You have no unread messages." : "Nu aveți mesaje necitite.",
-    "Users and groups" : "Utilizatori și grupuri",
-    "Users" : "Utilizatori",
-    "Groups" : "Grupuri",
-    "Other sources" : "Alte surse",
     "Conversation list" : "Lista de conversații",
     "Filter unread mentions" : "Filtrează mențiunile necitite",
     "Filter unread messages" : "Filtrează mesajele necitite",
@@ -629,9 +627,13 @@ OC.L10N.register(
     "New personal note" : "Notă personală nouă",
     "Clear filter" : "Șterge filtrul",
     "Unread mentions" : "Menționări necitite",
+    "Talk settings" : "Setări Talk",
+    "Users" : "Utilizatori",
+    "Groups" : "Grupuri",
     "Open conversations" : "Conversații deschise",
     "No search results" : "Căutarea nu are rezultate",
-    "Talk settings" : "Setări Talk",
+    "Users and groups" : "Utilizatori și grupuri",
+    "Other sources" : "Alte surse",
     "The meeting will start soon" : "Întâlnirea va începe în curând",
     "None" : "Niciuna",
     "Devices" : "Dispozitive",
@@ -859,8 +861,8 @@ OC.L10N.register(
     "Could not send invitation to {actorId}" : "Nu a fost trimisă invitația către {actorId}",
     "Invitations sent" : "Invitațiile au fost trimise",
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Încercați să participați la o conversație având o sesiune activă în altă fereastră sau dispozitiv. Acest lucru nu este suportat în prezent în Nextcloud Talk. Ce doriți să faceți?",
-    "Join here" : "Alăturare aici",
     "Leave this page" : "Părăsește pagina",
+    "Join here" : "Alăturare aici",
     "An error occurred while requesting assistance" : "Eroare la solicitarea de asistență",
     "An error occurred while resetting the request for assistance" : "Eroare la resetarea solicitării de asistență",
     "An error occurred while submitting your vote" : "Eroare la transmiterea votului",
