@@ -136,6 +136,8 @@ OC.L10N.register(
     "Message deleted by author" : "Messàgiu cantzelladu dae s'autore",
     "Message deleted by {actor}" : "Messàgiu cantzelladu dae {actor}",
     "Message deleted by you" : "Messàgiu cantzelladu dae tue",
+    "Administration" : "Amministratzione",
+    "System" : "Sistema",
     "%s (guest)" : "%s (persone invitada)",
     "Talk conversations" : "Resonadas de Talk",
     "Talk to %s" : "Faedda cun %s",
@@ -496,8 +498,8 @@ OC.L10N.register(
     "Invalid date, date format must be YYYY-MM-DD" : "Data non bàlida, su formadu de sa data depet èssere AAAA-MM-GG",
     "Conversation not found" : "Resonada no agatada",
     "Chat, video & audio-conferencing using WebRTC" : "Tzarradas, cunferèntzias vìdeo e àudio impreende WebRTC",
-    "Navigating away from the page will leave the call in {conversation}" : "Bessire dae sa pàgina at a fàghere lassare sa mutida in {conversation}",
     "Leave call" : "Lassa sa mutida",
+    "Navigating away from the page will leave the call in {conversation}" : "Bessire dae sa pàgina at a fàghere lassare sa mutida in {conversation}",
     "Stay in call" : "Abarra in sa mutida",
     "Discuss this file" : "Chistiona de custu archìviu",
     "Share this file with others to discuss it" : "Cumpartzi custu archìviu cun àtere pro nde chistionare",
@@ -563,7 +565,6 @@ OC.L10N.register(
     "Delete the signaling server account" : "Cantzella su contu de su serbidore de signalatzione",
     "_%n user_::_%n users_" : ["%nutente","%n utentes"],
     "Installed version: {version}" : "Versione installada: {version}",
-    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/.../nextcloud/apps/talk_matterbridge/bin/\"." : "Su binàriu de Matterbridge tenet autorizatziones non curretas. Assegura•ti chi s'archìviu binàriu de Matterbridge siat de propiedade s'utèntzia curreta e potzat èssere esecutadu. Ddu podes agatare in \"/.../nextcloud/apps/talk_matterbridge/bin/\".",
     "Matterbridge binary was not found or couldn't be executed." : "Su binàriu de Matterbridge non est istadu agatadu o non podet èssere esecutadu.",
     "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Podes agatare su percursu de su binàriu de Matterbridge a manu puru, cun sa cunfiguratzione. Controlla sa {linkstart}Documentatzione de s'integratzione de Matterbridge{linkend} pro àteras informatziones.",
     "Downloading …" : "Iscarrighende ...",
@@ -728,20 +729,20 @@ OC.L10N.register(
     "Conversation actions" : "Atziones de is resonadas",
     "No matches found" : "Peruna currispondèntzia agatada",
     "No conversations found" : "Peruna resonada agatada",
-    "Users and groups" : "Utentes e grupos",
-    "Users" : "Utentes",
-    "Groups" : "Grupos",
-    "Other sources" : "Àteras fontes",
     "An error occurred while performing the search" : "B'at àpidu un'errore in sa chirca",
     "Conversation list" : "Lista de is resonadas",
     "Create a new conversation" : "Crea una resonada noa",
     "New personal note" : "Nota personale noa",
     "Clear filter" : "Lìmpia filtru",
-    "New group conversation" : "Resonada de grupu noa",
-    "Open conversations" : "Aberre is resonadas",
-    "New private conversation" : "Resonada privada noa",
-    "No search results" : "Perunu resurtadu de chirca",
     "Talk settings" : "Cunfiguratzione de Talk",
+    "Users" : "Utentes",
+    "Groups" : "Grupos",
+    "New private conversation" : "Resonada privada noa",
+    "Open conversations" : "Aberre is resonadas",
+    "No search results" : "Perunu resurtadu de chirca",
+    "Users and groups" : "Utentes e grupos",
+    "Other sources" : "Àteras fontes",
+    "New group conversation" : "Resonada de grupu noa",
     "You are currently waiting in the lobby" : "Immoe ses abetende in s'intrada",
     "None" : "Perunu",
     "Select microphone" : "Seletziona su micròfonu",
@@ -1014,8 +1015,8 @@ OC.L10N.register(
     "Invitations sent" : "Invitos imbiados",
     "Error occurred when sending invitations" : "B'at àpidu un'errore imbiende is invitos",
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Ses proende a intrare in una resonada cun una sessione ativa in un'àtera ventana o dispositivu. In custu momentu cust'atzione no est suportada dae Nextcloud Talk. Ite boles fàghere?",
-    "Join here" : "Intra inoghe",
     "Leave this page" : "Lassa custa pàgina",
+    "Join here" : "Intra inoghe",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Su navigadore chi ses impreende no est suportadu totu dae Nextcloud. Imprea s'ùrtima versione de Mozilla Firefox, Microsoft Edge, Google Chrome, Opera o Apple Safari.",
     "Lost connection to signaling server. Trying to reconnect." : "Connessione pèrdida cun su serbidore de signalatzione. Proende a torrare a connètere",
     "Establishing signaling connection is taking longer than expected …" : "Sa creatzione de sa connessione de signalatzione est istentende prus de su tempus prevìdidu ...",
