@@ -134,6 +134,8 @@ OC.L10N.register(
     "Message deleted by author" : "Tin nhắn đã xóa bởi tác giả",
     "Message deleted by {actor}" : "Tin nhắn đã xóa bởi {actor}",
     "Message deleted by you" : "Tin nhắn đá xóa bởi bạn",
+    "Administration" : "Quản trị viên",
+    "System" : "Hệ thống",
     "%s (guest)" : "%s (khách mời)",
     "Talk to %s" : "Trò chuyện với %s",
     "File is not shared, or shared but not with the user" : "Tệp này không được chia sẻ, hoạc được chia sẻ nhưng không phải với người dùng này",
@@ -241,8 +243,8 @@ OC.L10N.register(
     "Invalid date, date format must be YYYY-MM-DD" : "Định dạng ngày không hợp lệ phải là YYYY-MM-DD",
     "Conversation not found" : "Không tìm thấy cuộc hội thoại",
     "Chat, video & audio-conferencing using WebRTC" : "Trò chuyện, hội thảo âm thanh và video bằng WebRTC",
-    "Navigating away from the page will leave the call in {conversation}" : "Điều hướng khỏi trang sẽ rời khỏi cuộc gọi trong {cuộc trò chuyện}",
     "Leave call" : "Rời khỏi cuộc gọi",
+    "Navigating away from the page will leave the call in {conversation}" : "Điều hướng khỏi trang sẽ rời khỏi cuộc gọi trong {cuộc trò chuyện}",
     "Stay in call" : "Giữ cuộc gọi",
     "Discuss this file" : "Thảo luận về tệp này",
     "Share this file with others to discuss it" : "Chia sẻ tệp này với những người khác để thảo luận về nó",
@@ -303,7 +305,6 @@ OC.L10N.register(
     "Delete the signaling server account" : "Xóa tài khoản máy chủ báo hiệu",
     "_%n user_::_%n users_" : ["%n người dùng"],
     "Installed version: {version}" : "Phiên bản đã cài đặt: {version}",
-    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/.../nextcloud/apps/talk_matterbridge/bin/\"." : "Nhị phân Matterbridge có quyền không chính xác. Hãy đảm bảo rằng tệp nhị phân Matterbridge thuộc sở hữu của đúng người dùng và có thể được thực thi.",
     "Matterbridge binary was not found or couldn't be executed." : "Nhị phân Matterbridge không được tìm thấy hoặc không thể được thực thi",
     "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Bạn cũng có thể đặt đường dẫn đến nhị phân Matterbridge theo cách thủ công thông qua cấu hình. Kiểm tra {linkstart} tài liệu tích hợp Matterbridge {linkend} để biết thêm thông tin.",
     "Downloading …" : "Đang tải ...",
@@ -449,16 +450,16 @@ OC.L10N.register(
     "You need to promote a new moderator before you can leave the conversation." : "Bạn cần chọn người kiểm duyệt mới trước khi có thể rời khỏi cuộc trò chuyện.",
     "Conversation actions" : "Hoạt động cuộc trò chuyện",
     "No conversations found" : "Không tìm thấy cuộc trò chuyện nào",
-    "Users and groups" : "Người dùng và nhóm",
-    "Users" : "Người dùng",
-    "Groups" : "Nhóm",
-    "Other sources" : "Những nguồn khác",
     "An error occurred while performing the search" : "Đã xảy ra lỗi khi thực hiện tìm kiếm",
     "Conversation list" : "Danh sách cuộc trò chuyện",
     "Clear filter" : "Xóa bộ lọc",
+    "Talk settings" : "Cài đặt Talk",
+    "Users" : "Người dùng",
+    "Groups" : "Nhóm",
     "Open conversations" : "Mở cuộc trò chuyện",
     "No search results" : "Không có kết quả tìm kiếm",
-    "Talk settings" : "Cài đặt Talk",
+    "Users and groups" : "Người dùng và nhóm",
+    "Other sources" : "Những nguồn khác",
     "You are currently waiting in the lobby" : "Bạn hiện đang đợi ở sảnh đợi",
     "None" : "Không có",
     "Select microphone" : "Chọn micrô",
@@ -682,8 +683,8 @@ OC.L10N.register(
     "Invitations sent" : "Lời mời đã được gửi",
     "Error occurred when sending invitations" : "Đã xảy ra lỗi khi gửi lời mời",
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Bạn đang cố gắng tham gia một cuộc trò chuyện trong khi có một phiên hoạt động trong một cửa sổ hoặc thiết bị khác. Điều này hiện không được vWorkspace Talk hỗ trợ. Bạn muốn làm gì?",
-    "Join here" : "Tham gia tại đây",
     "Leave this page" : "Rời khỏi trang này",
+    "Join here" : "Tham gia tại đây",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Trình duyệt bạn đang sử dụng không được vWorkspace Talk hỗ trợ đầy đủ. Vui lòng sử dụng phiên bản mới nhất của Mozilla Firefox, Microsoft Edge, Google Chrome, Opera hoặc Apple Safari.",
     "Lost connection to signaling server. Trying to reconnect." : "Mất kết nối với máy chủ báo hiệu. Đang cố gắng kết nối lại.",
     "Establishing signaling connection is taking longer than expected …" : "Việc thiết lập kết nối báo hiệu mất nhiều thời gian hơn dự kiến…",
