@@ -1222,7 +1222,7 @@ class ParticipantService {
 	 * @psalm-param int-mask-of<Participant::FLAG_*> $flags
 	 * @throws \InvalidArgumentException
 	 */
-	public function changeInCall(Room $room, Participant $participant, int $flags, bool $endCallForEveryone = false, bool $silent = false): void {
+	public function changeInCall(Room $room, Participant $participant, int $flags, bool $endCallForEveryone = false, bool $silent = false, int $lastJoinedCall = 0): void {
 		if ($room->getType() === Room::TYPE_CHANGELOG
 			|| $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER
 			|| $room->getType() === Room::TYPE_NOTE_TO_SELF) {
@@ -1261,7 +1261,7 @@ class ParticipantService {
 
 		$attendee = $participant->getAttendee();
 		if ($flags !== Participant::FLAG_DISCONNECTED) {
-			$attendee->setLastJoinedCall($this->timeFactory->getTime());
+			$attendee->setLastJoinedCall($lastJoinedCall ?: $this->timeFactory->getTime());
 			$this->attendeeMapper->update($attendee);
 		} elseif ($attendee->getActorType() === Attendee::ACTOR_PHONES) {
 			$attendee->setCallId('');
@@ -2190,6 +2190,13 @@ class ParticipantService {
 			return $this->getParticipant($room, $actorId, false);
 		}
 
+		if ($actorType === Attendee::ACTOR_GUESTS
+			&& in_array($actorId, [Attendee::ACTOR_ID_CLI, Attendee::ACTOR_ID_SYSTEM, Attendee::ACTOR_ID_CHANGELOG, Attendee::ACTOR_ID_SAMPLE], true)) {
+			$exception = new ParticipantNotFoundException('User is not a participant');
+			$this->logger->info('Trying to load hardcoded system guest from attendees table: ' . $actorType . '/' . $actorId);
+			throw $exception;
+		}
+
 		$query = $this->connection->getQueryBuilder();
 		$helper = new SelectHelper();
 		$helper->selectAttendeesTable($query);
